Bagua
======
[![Generic badge](https://img.shields.io/badge/website-up-green.svg)](https://baguasys.github.io/tutorials/) [![Documentation Status](https://readthedocs.org/projects/bagua/badge/?version=latest)](http://bagua.readthedocs.io/?badge=latest) [![PyPI version](https://badge.fury.io/py/bagua.svg)](https://badge.fury.io/py/bagua) [![Docker](https://img.shields.io/badge/docker-pass-green)](https://hub.docker.com/r/baguasys/bagua) [![GitHub license](https://img.shields.io/github/license/BaguaSys/bagua)](https://github.com/BaguaSys/bagua/blob/master/LICENSE)

## Installation

Develop version:

```
pip install git+https://github.com/BaguaSys/bagua.git
```

Release version:

```
pip install bagua
```

## Build API documentation locally

```
pip install -r docs/doc-requirements.txt
make html
```
